@@ -18,26 +18,22 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Create Command Module."""
-from __future__ import annotations
 
-import logging
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import click
-
-from molecule.api import drivers
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
-from molecule.config import DEFAULT_DRIVER
+from molecule.reporting.definitions import CompletionState
 
 
 if TYPE_CHECKING:
+    import click
+
     from molecule.types import CommandArgs, MoleculeArgs
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Create(base.Base):
     """Create Command Class."""
 
@@ -51,7 +47,8 @@ class Create(base.Base):
 
         if self._config.state.created:
             msg = "Skipping, instances already created."
-            LOG.warning(msg)
+            self._log.warning(msg)
+            self._config.scenario.results.add_completion(CompletionState.skipped(note=msg))
             return
 
         if self._config.provisioner:
@@ -60,34 +57,29 @@ class Create(base.Base):
         self._config.state.change_state("created", value=True)
 
 
-@base.click_command_ex()
-@click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
-@click.option(
-    "--driver-name",
-    "-d",
-    type=click.Choice([str(s) for s in drivers()]),
-    help=f"Name of driver to use. ({DEFAULT_DRIVER})",
-)
-def create(
-    ctx: click.Context,
-    scenario_name: str,
-    driver_name: str,
-) -> None:  # pragma: no cover
+@click_command_ex()
+@common_options("driver_name_with_choices")
+def create(ctx: click.Context) -> None:  # pragma: no cover
     """Use the provisioner to start the instances.
 
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        driver_name: Name of the Molecule driver to use.
     """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand, "driver_name": driver_name}
+    command_args: CommandArgs = {
+        "command_borders": ctx.params["command_borders"],
+        "driver_name": ctx.params["driver_name"],
+        "report": ctx.params["report"],
+        "shared_state": ctx.params["shared_state"],
+        "subcommand": subcommand,
+    }
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args)
+    __all = ctx.params["all"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
+
+    if __all:
+        scenario_name = None
+
+    base.execute_cmdline_scenarios(scenario_name, args, command_args, excludes=exclude)
