@@ -21,22 +21,18 @@
 
 from __future__ import annotations
 
-import logging
-
 from typing import TYPE_CHECKING
 
-import click
-
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
 
 
 if TYPE_CHECKING:
+    import click
+
     from molecule.types import CommandArgs, MoleculeArgs
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Dependency(base.Base):
     """Dependency Command Class."""
 
@@ -50,38 +46,27 @@ class Dependency(base.Base):
             self._config.dependency.execute()
 
 
-@base.click_command_ex()
-@click.pass_context
-@base.click_command_options
-def dependency(
-    ctx: click.Context,
-    /,
-    scenario_name: list[str] | None,
-    exclude: list[str],
-    *,
-    __all: bool,
-    report: bool,
-    shared_inventory: bool,
-) -> None:  # pragma: no cover
+@click_command_ex()
+@common_options()
+def dependency(ctx: click.Context) -> None:  # pragma: no cover
     """Manage the role's dependencies.
 
-    \f
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        exclude: Name of the scenarios to avoid targeting.
-        __all: Whether molecule should target scenario_name or all scenarios.
-        report: Whether to show an after-run summary report.
-        shared_inventory: Whether the inventory should be shared between scenarios.
-    """  # noqa: D301
+    """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {
+        "command_borders": ctx.params["command_borders"],
+        "report": ctx.params["report"],
+        "shared_state": ctx.params["shared_state"],
         "subcommand": subcommand,
-        "report": report,
-        "shared_inventory": shared_inventory,
     }
 
+    __all = ctx.params["all"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
+
     if __all:
         scenario_name = None
 
