@@ -22,7 +22,6 @@
 from __future__ import annotations
 
 import json
-import logging
 import os
 import sys
 
@@ -31,16 +30,19 @@ from typing import TYPE_CHECKING
 
 import click
 
-from molecule import api
-from molecule.command import base as command_base
+from molecule import logger, util
+from molecule.click_cfg import click_command_ex
 from molecule.command.init import base
 from molecule.config import (
-    DEFAULT_DRIVER,
     MOLECULE_EMBEDDED_DATA_DIR,
     Config,
     molecule_directory,
 )
-from molecule.exceptions import MoleculeError
+from molecule.constants import (
+    MOLECULE_COLLECTION_ROOT,
+    MOLECULE_DEFAULT_SCENARIO_NAME,
+    MOLECULE_ROOT,
+)
 
 
 if TYPE_CHECKING:
@@ -50,23 +52,14 @@ if TYPE_CHECKING:
         """Argument dictionary to pass to init-scenario playbook.
 
         Attributes:
-            dependency_name: Name of the dependency to initialize.
-            driver_name: Name of the driver to initialize.
-            provisioner_name: Name of the provisioner to initialize.
             scenario_name: Name of the scenario to initialize.
             subcommand: Name of subcommand to initialize.
         """
 
-        dependency_name: str
-        driver_name: str
-        provisioner_name: str
         scenario_name: str
         subcommand: str
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Scenario(base.Base):
     """Scenario Class.
 
@@ -99,26 +92,41 @@ class Scenario(base.Base):
         """
         self._config = config
         self._command_args = command_args
+        # For init scenario, use the scenario name from command args
+        scenario_name = command_args.get("scenario_name", "unknown")
+        self._log = logger.get_scenario_logger(__name__, scenario_name, "init")
 
     def execute(self, action_args: list[str] | None = None) -> None:  # noqa: ARG002
         """Execute the actions necessary to perform a `molecule init scenario`.
 
         Args:
             action_args: Arguments for this command. Unused.
-
-        Raises:
-            MoleculeError: when the scenario cannot be created.
         """
         scenario_name = self._command_args["scenario_name"]
 
         msg = f"Initializing new scenario {scenario_name}..."
-        LOG.info(msg)
-        molecule_path = Path(molecule_directory(Path.cwd()))
+        self._log.info(msg)
+
+        # Use collection-aware molecule directory
+        collection_dir, _ = util.get_collection_metadata()
+
+        if collection_dir:
+            # We're in collection mode, use extensions/molecule
+            molecule_path = collection_dir / MOLECULE_COLLECTION_ROOT
+            relative_path = f"{MOLECULE_COLLECTION_ROOT}/{scenario_name}"
+        else:
+            # Standard mode, use molecule/
+            molecule_path = Path(molecule_directory(Path.cwd()))
+            relative_path = f"{MOLECULE_ROOT}/{scenario_name}"
+
         scenario_directory = molecule_path / scenario_name
 
         if scenario_directory.is_dir():
-            msg = f"The directory molecule/{scenario_name} exists. Cannot create new scenario."
-            raise MoleculeError(msg)
+            msg = f"The directory {relative_path} exists. Cannot create new scenario."
+            util.sysexit_with_message(msg, code=1)
+
+        # Ensure parent directory exists
+        molecule_path.mkdir(parents=True, exist_ok=True)
 
         extra_vars = json.dumps(self._command_args)
         cmd = [
@@ -135,10 +143,15 @@ class Scenario(base.Base):
         # it to use colors.
         env["ANSIBLE_FORCE_COLOR"] = "1"
         env["ANSIBLE_PYTHON_INTERPRETER"] = sys.executable
-        self._config.app.run_command(cmd, env=env, check=True)
+        self._config.app.run_command(
+            cmd,
+            env=env,
+            check=True,
+            command_borders=self._config.command_borders,
+        )
 
         msg = f"Initialized scenario in {scenario_directory} successfully."
-        LOG.info(msg)
+        self._log.info(msg)
 
 
 def _role_exists(
@@ -154,59 +167,30 @@ def _role_exists(
     role_directory = Path.cwd().parent / value
     if not role_directory.exists():
         msg = f"The role '{value}' not found. Please choose the proper role name."
-        raise MoleculeError(msg)
+        util.sysexit_with_message(msg, code=1)
     return value
 
 
-@command_base.click_command_ex()
+@click_command_ex()
 @click.pass_context
-@click.option(
-    "--dependency-name",
-    type=click.Choice(["galaxy"]),
-    default="galaxy",
-    help="Name of dependency to initialize. (galaxy)",
-)
-@click.option(
-    "--driver-name",
-    "-d",
-    type=click.Choice([str(s) for s in api.drivers()]),
-    default=DEFAULT_DRIVER,
-    help=f"Name of driver to initialize. ({DEFAULT_DRIVER})",
-)
-@click.option(
-    "--provisioner-name",
-    type=click.Choice(["ansible"]),
-    default="ansible",
-    help="Name of provisioner to initialize. (ansible)",
-)
 @click.argument(
     "scenario-name",
-    default=command_base.MOLECULE_DEFAULT_SCENARIO_NAME,
+    default=MOLECULE_DEFAULT_SCENARIO_NAME,
     required=False,
 )
 def scenario(
     ctx: click.Context,  # noqa: ARG001
-    dependency_name: str,
-    driver_name: str,
-    provisioner_name: str,
     scenario_name: str,
 ) -> None:  # pragma: no cover
     """Initialize a new scenario for use with Molecule.
 
     If name is not specified the 'default' value will be used.
 
-    \f
     Args:
         ctx: Click context object holding commandline arguments.
-        dependency_name: Name of dependency to initialize.
-        driver_name: Name of driver to use.
-        provisioner_name: Name of provisioner to use.
         scenario_name: Name of scenario to initialize.
-    """  # noqa: D301
+    """
     command_args: CommandArgs = {
-        "dependency_name": dependency_name,
-        "driver_name": driver_name,
-        "provisioner_name": provisioner_name,
         "scenario_name": scenario_name,
         "subcommand": __name__,
     }
