@@ -21,11 +21,10 @@
 
 from __future__ import annotations
 
-import logging
-
 from typing import TYPE_CHECKING
 
 from molecule.dependency import base
+from molecule.reporting.definitions import CompletionState
 
 
 if TYPE_CHECKING:
@@ -34,48 +33,8 @@ if TYPE_CHECKING:
     from molecule.config import Config
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Shell(base.Base):
-    """``Shell`` is an alternate dependency manager.
-
-    It is intended to run a command in situations where `Ansible Galaxy`_
-    don't suffice.
-
-    The ``command`` to execute is required, and is relative to Molecule's
-    project directory when referencing a script not in $PATH.
-
-    !!! note
-
-        Unlike the other dependency managers, ``options`` are ignored and not
-        passed to `shell`.  Additional flags/subcommands should simply be added
-        to the `command`.
-
-    ``` yaml
-        dependency:
-          name: shell
-          command: path/to/command --flag1 subcommand --flag2
-    ```
-
-    The dependency manager can be disabled by setting ``enabled`` to False.
-
-    ``` yaml
-        dependency:
-          name: shell
-          command: path/to/command --flag1 subcommand --flag2
-          enabled: False
-    ```
-    Environment variables can be passed to the dependency.
-
-    ``` yaml
-        dependency:
-          name: shell
-          command: path/to/command --flag1 subcommand --flag2
-          env:
-            FOO: bar
-    ```
-    """
+    """The Shell dependency."""
 
     def __init__(self, config: Config) -> None:
         """Construct Shell.
@@ -116,7 +75,8 @@ class Shell(base.Base):
         """
         if not self.enabled:
             msg = "Skipping, dependency is disabled."
-            LOG.warning(msg)
+            self._log.warning(msg)
+            self._config.scenario.results.add_completion(CompletionState.disabled)
             return
         super().execute()
 
