@@ -21,13 +21,12 @@
 
 from __future__ import annotations
 
-import logging
 import os
 
 from pathlib import Path
 from typing import TYPE_CHECKING
 
-from molecule import util
+from molecule import logger, util
 
 
 if TYPE_CHECKING:
@@ -46,9 +45,6 @@ if TYPE_CHECKING:
     ]
 
 
-LOG = logging.getLogger(__name__)
-
-
 class AnsiblePlaybooks:
     """A class to act as a module to namespace playbook properties."""
 
@@ -60,6 +56,17 @@ class AnsiblePlaybooks:
         """
         self._config = config
 
+    @property
+    def _log(self) -> logger.ScenarioLoggerAdapter:
+        """Get a fresh scenario logger with current context.
+
+        Returns:
+            A scenario logger adapter with current scenario and step context.
+        """
+        # Get step context from the current action being executed
+        step_name = getattr(self._config, "action", "provisioner")
+        return logger.get_scenario_logger(__name__, self._config.scenario.name, step_name)
+
     @property
     def cleanup(self) -> str | None:
         """Get the cleanup playbook path.
@@ -143,16 +150,9 @@ class AnsiblePlaybooks:
             The playbook path, or none if one is not needed.
         """
         c = self._config.config
-        driver_dict: dict[Section, str | None] | None = c["provisioner"]["playbooks"].get(  # type: ignore[assignment]
-            self._config.driver.name,
-        )
 
-        playbook: str | None = c["provisioner"]["playbooks"][section]
-        if driver_dict:
-            try:
-                playbook = driver_dict[section]
-            except Exception as exc:
-                LOG.exception(exc)  # noqa: TRY401
+        playbook: str | None = c["ansible"]["playbooks"][section]
+
         if self._config.provisioner and playbook is not None:
             playbook = self._config.provisioner.abs_path(playbook)
             if playbook:
@@ -183,14 +183,14 @@ class AnsiblePlaybooks:
         path = Path(
             self._get_playbook_directory(),
             self._config.driver.name,
-            self._config.config["provisioner"]["playbooks"][section],
+            self._config.config["ansible"]["playbooks"][section],
         )
         if path.exists():
             return str(path)
         path = Path(
             self._config.driver._path,  # noqa: SLF001
             "playbooks",
-            self._config.config["provisioner"]["playbooks"][section],
+            self._config.config["ansible"]["playbooks"][section],
         )
         return str(path)
 
@@ -214,7 +214,7 @@ class AnsiblePlaybooks:
         if basename in pb_rename_map:
             fb_playbook = play_path.parent / pb_rename_map[basename]
             if fb_playbook.is_file():
-                LOG.warning(
+                self._log.warning(
                     "%s was deprecated, rename it to %s",
                     fb_playbook.name,
                     basename,
